Arena

Struct Arena 

pub struct Arena { /* private fields */ }
A memory-mapped arena for zero-copy data storage.

The Arena is the owner of the mmap and provides both read and write access. For concurrent access patterns, use ArenaReader and ArenaWriter.

Implementations

Source

impl Arena

pub fn create(trace_id: TraceId, config: &ArenaConfig) -> Result<Self>

Create a new arena for the given trace.

pub fn open(path: impl AsRef<Path>) -> Result<Self>

Open an existing arena file.

pub fn trace_id(&self) -> TraceId

Get the trace ID for this arena.

pub fn write_position(&self) -> ArenaOffset

Get the current write position.

pub fn available_space(&self) -> u64

Get available space in bytes.

pub fn path(&self) -> PathBuf

Get the path to the arena file.

pub fn write_bytes<T>(&self, bytes: &[u8]) -> Result<RelPtr<T>>

Write serialized bytes to the arena and return a relative pointer.

pub fn read_bytes(&self, offset: ArenaOffset, size: usize) -> Result<Vec<u8>>

Read bytes from the arena.

pub fn flush(&self) -> Result<()>

Flush all pending writes to disk.

pub fn reader(&self) -> ArenaReader

Create a reader handle for this arena.

pub fn writer(&self) -> ArenaWriter

Create a writer handle for this arena.