pub struct CompatibilityReport {
pub compatible: bool,
pub changes: Vec<SchemaChange>,
pub migration_required: bool,
pub migration_available: bool,
pub summary: String,
}Expand description
Compatibility check result.
Contains details about whether two schemas are compatible, what changes exist between them, and if migration is required.
Fields
compatible: boolWhether the schemas are directly compatible without requiring migration.
changes: Vec<SchemaChange>List of all changes detected between the schemas.
migration_required: boolWhether a migration is required to use old data with the new schema.
migration_available: boolWhether a migration function is available for this transformation.
summary: StringHuman-readable summary of the compatibility check result.
Implementations
Sourceimpl CompatibilityReport
impl CompatibilityReport
Sourcepub fn compatible() -> Self
pub fn compatible() -> Self
Create a compatibility report indicating full compatibility.
Sourcepub fn incompatible(
changes: Vec<SchemaChange>,
migration_available: bool,
) -> Self
pub fn incompatible( changes: Vec<SchemaChange>, migration_available: bool, ) -> Self
Create a compatibility report indicating incompatibility.
Sourcepub fn has_breaking_changes(&self) -> bool
pub fn has_breaking_changes(&self) -> bool
Check if there are any breaking changes.
Sourcepub fn breaking_changes(&self) -> Vec<&SchemaChange>
pub fn breaking_changes(&self) -> Vec<&SchemaChange>
Get all breaking changes.
Sourcepub fn non_breaking_changes(&self) -> Vec<&SchemaChange>
pub fn non_breaking_changes(&self) -> Vec<&SchemaChange>
Get all non-breaking changes.