pub struct TraceRecoveryState {
pub trace_id: TraceId,
pub last_completed_node: Option<NodeId>,
pub suspended_at: Option<NodeId>,
pub started_nodes: Vec<NodeId>,
pub completed_nodes: HashMap<NodeId, NodeOutputLocation>,
}Expand description
State needed to recover an incomplete trace.
Fields
trace_id: TraceIdThe trace identifier.
last_completed_node: Option<NodeId>The last node that completed successfully (if any).
suspended_at: Option<NodeId>Node where the trace is currently suspended (if any).
started_nodes: Vec<NodeId>Nodes that have started execution but did not complete.
completed_nodes: HashMap<NodeId, NodeOutputLocation>Map of completed nodes to their output locations in the arena.