pub struct Arena { /* private fields */ }Expand description
A memory-mapped arena for zero-copy data storage.
The Arena is the owner of the mmap and provides both read and write access.
For concurrent access patterns, use ArenaReader and ArenaWriter.
Implementations
Sourceimpl Arena
impl Arena
Sourcepub fn create(trace_id: TraceId, config: &ArenaConfig) -> Result<Self>
pub fn create(trace_id: TraceId, config: &ArenaConfig) -> Result<Self>
Create a new arena for the given trace.
Sourcepub fn write_position(&self) -> ArenaOffset
pub fn write_position(&self) -> ArenaOffset
Get the current write position.
Sourcepub fn available_space(&self) -> u64
pub fn available_space(&self) -> u64
Get available space in bytes.
Sourcepub fn write_bytes<T>(&self, bytes: &[u8]) -> Result<RelPtr<T>>
pub fn write_bytes<T>(&self, bytes: &[u8]) -> Result<RelPtr<T>>
Write serialized bytes to the arena and return a relative pointer.
Sourcepub fn read_bytes(&self, offset: ArenaOffset, size: usize) -> Result<Vec<u8>>
pub fn read_bytes(&self, offset: ArenaOffset, size: usize) -> Result<Vec<u8>>
Read bytes from the arena.
Sourcepub fn reader(&self) -> ArenaReader
pub fn reader(&self) -> ArenaReader
Create a reader handle for this arena.
Sourcepub fn writer(&self) -> ArenaWriter
pub fn writer(&self) -> ArenaWriter
Create a writer handle for this arena.