pub struct DefaultRegistry { /* private fields */ }Expand description
Registry of default value providers.
Stores default providers for different schemas, enabling runtime lookup of field defaults during migration.
Implementations
Sourceimpl DefaultRegistry
impl DefaultRegistry
Sourcepub fn register(&self, schema: &str, provider: impl DefaultProvider + 'static)
pub fn register(&self, schema: &str, provider: impl DefaultProvider + 'static)
Register a default provider for a schema.
Register a shared default provider for a schema.
Sourcepub fn get_provider(&self, schema: &str) -> Option<Arc<dyn DefaultProvider>>
pub fn get_provider(&self, schema: &str) -> Option<Arc<dyn DefaultProvider>>
Get the default provider for a schema.
Sourcepub fn get_default(
&self,
schema: &str,
field: &str,
type_name: &str,
) -> Option<Vec<u8>>
pub fn get_default( &self, schema: &str, field: &str, type_name: &str, ) -> Option<Vec<u8>>
Get a default value for a field in a schema.
Sourcepub fn get_default_string(
&self,
schema: &str,
field: &str,
type_name: &str,
) -> Option<String>
pub fn get_default_string( &self, schema: &str, field: &str, type_name: &str, ) -> Option<String>
Get a default value as string representation.
Sourcepub fn has_default(&self, schema: &str, field: &str) -> bool
pub fn has_default(&self, schema: &str, field: &str) -> bool
Check if a field has a default in a schema.
Sourcepub fn unregister(&self, schema: &str) -> bool
pub fn unregister(&self, schema: &str) -> bool
Unregister a default provider.