pub struct MigrationRegistry { /* private fields */ }Expand description
Registry of schema migrations.
Stores migrations between schema versions and provides path-finding for multi-hop migrations (e.g., v1 → v2 → v3).
Implementations
Sourceimpl MigrationRegistry
impl MigrationRegistry
Sourcepub fn register(&self, migration: Migration) -> Result<()>
pub fn register(&self, migration: Migration) -> Result<()>
Register a migration.
If a migration between the same schemas already exists, it is replaced.
Sourcepub fn unregister(&self, from_hash: u64, to_hash: u64) -> Option<Migration>
pub fn unregister(&self, from_hash: u64, to_hash: u64) -> Option<Migration>
Unregister a migration.
Sourcepub fn find_direct(&self, from_hash: u64, to_hash: u64) -> Option<Migration>
pub fn find_direct(&self, from_hash: u64, to_hash: u64) -> Option<Migration>
Find a direct migration from one schema to another.
Sourcepub fn find_path(&self, from_hash: u64, to_hash: u64) -> Option<Vec<Migration>>
pub fn find_path(&self, from_hash: u64, to_hash: u64) -> Option<Vec<Migration>>
Find the migration path from one schema to another.
Returns the migrations in order, or None if no path exists.
Sourcepub fn migrate(
&self,
arena: &Arena,
offset: ArenaOffset,
from_hash: u64,
to_hash: u64,
) -> Result<ArenaOffset>
pub fn migrate( &self, arena: &Arena, offset: ArenaOffset, from_hash: u64, to_hash: u64, ) -> Result<ArenaOffset>
Apply migration to arena data.
Finds the migration path and applies each migration in sequence.
Sourcepub fn migrations_from(&self, from_hash: u64) -> Vec<Migration>
pub fn migrations_from(&self, from_hash: u64) -> Vec<Migration>
Get migrations from a specific schema.
Sourcepub fn migrations_to(&self, to_hash: u64) -> Vec<Migration>
pub fn migrations_to(&self, to_hash: u64) -> Vec<Migration>
Get migrations to a specific schema.